@@ -32,6 +32,7 @@
 
 #include "rtklib_solver.h"
 #include "Beidou_DNAV.h"
+#include "gnss_sdr_filesystem.h"
 #include "rtklib_conversions.h"
 #include "rtklib_rtkpos.h"
 #include "rtklib_solution.h"
@@ -41,36 +42,15 @@
 #include <utility>
 #include <vector>
 
-// clang-format off
-#if HAS_STD_FILESYSTEM
-#include <system_error>
-namespace errorlib = std;
-#if HAS_STD_FILESYSTEM_EXPERIMENTAL
-#include <experimental/filesystem>
-namespace fs = std::experimental::filesystem;
-#else
-#include <filesystem>
-namespace fs = std::filesystem;
-#endif
-#else
-#include <boost/filesystem/operations.hpp>   // for create_directories, exists
-#include <boost/filesystem/path.hpp>         // for path, operator<<
-#include <boost/filesystem/path_traits.hpp>  // for filesystem
-#include <boost/system/error_code.hpp>       // for error_code
-namespace fs = boost::filesystem;
-namespace errorlib = boost::system;
-#endif
-// clang-format on
 
-
-Rtklib_Solver::Rtklib_Solver(const rtk_t &rtk, int nchannels, const std::string &dump_filename, bool flag_dump_to_file, bool flag_dump_to_mat)
+Rtklib_Solver::Rtklib_Solver(const rtk_t &rtk,
+    const std::string &dump_filename,
+    bool flag_dump_to_file,
+    bool flag_dump_to_mat) : d_rtk(rtk),
+                             d_dump_filename(dump_filename),
+                             d_flag_dump_enabled(flag_dump_to_file),
+                             d_flag_dump_mat_enabled(flag_dump_to_mat)
 {
-    // init empty ephemeris for all the available GNSS channels
-    rtk_ = rtk;
-    d_nchannels = nchannels;
-    d_dump_filename = dump_filename;
-    d_flag_dump_enabled = flag_dump_to_file;
-    d_flag_dump_mat_enabled = flag_dump_to_mat;
     this->set_averaging_flag(false);
 
     // ############# ENABLE DATA FILE LOG #################
@@ -371,31 +351,31 @@ bool Rtklib_Solver::save_matfile() const
 
 double Rtklib_Solver::get_gdop() const
 {
-    return dop_[0];
+    return d_dop[0];
 }
 
 
 double Rtklib_Solver::get_pdop() const
 {
-    return dop_[1];
+    return d_dop[1];
 }
 
 
 double Rtklib_Solver::get_hdop() const
 {
-    return dop_[2];
+    return d_dop[2];
 }
 
 
 double Rtklib_Solver::get_vdop() const
 {
-    return dop_[3];
+    return d_dop[3];
 }
 
 
 Monitor_Pvt Rtklib_Solver::get_monitor_pvt() const
 {
-    return monitor_pvt;
+    return d_monitor_pvt;
 }
 
 
@@ -418,7 +398,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
     int valid_obs = 0;      // valid observations counter
     int glo_valid_obs = 0;  // GLONASS L1/L2 valid observations counter
 
-    obs_data.fill({});
+    d_obs_data.fill({});
     std::vector<eph_t> eph_data(MAXOBS);
     std::vector<geph_t> geph_data(MAXOBS);
 
@@ -426,6 +406,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
     bool gps_dual_band = false;
     bool band1 = false;
     bool band2 = false;
+    bool gal_e5_is_e5b = false;
     for (gnss_observables_iter = gnss_observables_map.cbegin();
          gnss_observables_iter != gnss_observables_map.cend();
          ++gnss_observables_iter)
@@ -475,9 +456,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                         eph_data[valid_obs] = eph_to_rtklib(galileo_ephemeris_iter->second);
                                         // convert observation from GNSS-SDR class to RTKLIB structure
                                         obsd_t newobs{};
-                                        obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                        d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                             gnss_observables_iter->second,
-                                            galileo_ephemeris_iter->second.WN_5,
+                                            galileo_ephemeris_iter->second.WN,
                                             0);
                                         valid_obs++;
                                     }
@@ -488,7 +469,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                             }
 
                         // Galileo E5
-                        if (sig_ == "5X")
+                        if ((sig_ == "5X") || (sig_ == "7X"))
                             {
                                 // 1 Gal - find the ephemeris for the current GALILEO SV observation. The SV PRN ID is the map key
                                 galileo_ephemeris_iter = galileo_ephemeris_map.find(gnss_observables_iter->second.PRN);
@@ -499,9 +480,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                             {
                                                 if (eph_data[i].sat == (static_cast<int>(gnss_observables_iter->second.PRN + NSATGPS + NSATGLO)))
                                                     {
-                                                        obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(obs_data[i + glo_valid_obs],
+                                                        d_obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(d_obs_data[i + glo_valid_obs],
                                                             gnss_observables_iter->second,
-                                                            galileo_ephemeris_iter->second.WN_5,
+                                                            galileo_ephemeris_iter->second.WN,
                                                             2);  // Band 3 (L5/E5)
                                                         found_E1_obs = true;
                                                         break;
@@ -517,9 +498,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                 obsd_t newobs = {{0, 0}, '0', '0', {}, {},
                                                     {default_code_, default_code_, default_code_},
                                                     {}, {0.0, 0.0, 0.0}, {}};
-                                                obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                                d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                                     gnss_observables_iter->second,
-                                                    galileo_ephemeris_iter->second.WN_5,
+                                                    galileo_ephemeris_iter->second.WN,
                                                     2);  // Band 3 (L5/E5)
                                                 valid_obs++;
                                             }
@@ -528,6 +509,10 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                     {
                                         DLOG(INFO) << "No ephemeris data for SV " << gnss_observables_iter->second.PRN;
                                     }
+                                if (sig_ == "7X")
+                                    {
+                                        gal_e5_is_e5b = true;
+                                    }
                             }
                         break;
                     }
@@ -545,9 +530,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                         eph_data[valid_obs] = eph_to_rtklib(gps_ephemeris_iter->second, this->is_pre_2009());
                                         // convert observation from GNSS-SDR class to RTKLIB structure
                                         obsd_t newobs{};
-                                        obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                        d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                             gnss_observables_iter->second,
-                                            gps_ephemeris_iter->second.i_GPS_week,
+                                            gps_ephemeris_iter->second.WN,
                                             0,
                                             this->is_pre_2009());
                                         valid_obs++;
@@ -575,7 +560,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                         if (eph_data[i].sat == static_cast<int>(gnss_observables_iter->second.PRN))
                                                             {
                                                                 eph_data[i] = eph_to_rtklib(gps_cnav_ephemeris_iter->second);
-                                                                obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(obs_data[i + glo_valid_obs],
+                                                                d_obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(d_obs_data[i + glo_valid_obs],
                                                                     gnss_observables_iter->second,
                                                                     eph_data[i].week,
                                                                     1);  // Band 2 (L2)
@@ -594,9 +579,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                 obsd_t newobs = {{0, 0}, '0', '0', {}, {},
                                                     {default_code_, default_code_, default_code_},
                                                     {}, {0.0, 0.0, 0.0}, {}};
-                                                obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                                d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                                     gnss_observables_iter->second,
-                                                    gps_cnav_ephemeris_iter->second.i_GPS_week,
+                                                    gps_cnav_ephemeris_iter->second.WN,
                                                     1);  // Band 2 (L2)
                                                 valid_obs++;
                                             }
@@ -623,9 +608,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                         if (eph_data[i].sat == static_cast<int>(gnss_observables_iter->second.PRN))
                                                             {
                                                                 eph_data[i] = eph_to_rtklib(gps_cnav_ephemeris_iter->second);
-                                                                obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(obs_data[i],
+                                                                d_obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(d_obs_data[i],
                                                                     gnss_observables_iter->second,
-                                                                    gps_cnav_ephemeris_iter->second.i_GPS_week,
+                                                                    gps_cnav_ephemeris_iter->second.WN,
                                                                     2);  // Band 3 (L5)
                                                                 break;
                                                             }
@@ -641,9 +626,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                 obsd_t newobs = {{0, 0}, '0', '0', {}, {},
                                                     {default_code_, default_code_, default_code_},
                                                     {}, {0.0, 0.0, 0.0}, {}};
-                                                obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                                d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                                     gnss_observables_iter->second,
-                                                    gps_cnav_ephemeris_iter->second.i_GPS_week,
+                                                    gps_cnav_ephemeris_iter->second.WN,
                                                     2);  // Band 3 (L5)
                                                 valid_obs++;
                                             }
@@ -669,7 +654,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                         geph_data[glo_valid_obs] = eph_to_rtklib(glonass_gnav_ephemeris_iter->second, gnav_utc);
                                         // convert observation from GNSS-SDR class to RTKLIB structure
                                         obsd_t newobs{};
-                                        obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                        d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                             gnss_observables_iter->second,
                                             glonass_gnav_ephemeris_iter->second.d_WN,
                                             0);  // Band 0 (L1)
@@ -692,7 +677,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                             {
                                                 if (geph_data[i].sat == (static_cast<int>(gnss_observables_iter->second.PRN + NSATGPS)))
                                                     {
-                                                        obs_data[i + valid_obs] = insert_obs_to_rtklib(obs_data[i + valid_obs],
+                                                        d_obs_data[i + valid_obs] = insert_obs_to_rtklib(d_obs_data[i + valid_obs],
                                                             gnss_observables_iter->second,
                                                             glonass_gnav_ephemeris_iter->second.d_WN,
                                                             1);  // Band 1 (L2)
@@ -707,7 +692,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                 geph_data[glo_valid_obs] = eph_to_rtklib(glonass_gnav_ephemeris_iter->second, gnav_utc);
                                                 // convert observation from GNSS-SDR class to RTKLIB structure
                                                 obsd_t newobs{};
-                                                obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                                d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                                     gnss_observables_iter->second,
                                                     glonass_gnav_ephemeris_iter->second.d_WN,
                                                     1);  // Band 1 (L2)
@@ -735,9 +720,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                         eph_data[valid_obs] = eph_to_rtklib(beidou_ephemeris_iter->second);
                                         // convert observation from GNSS-SDR class to RTKLIB structure
                                         obsd_t newobs{};
-                                        obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                        d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                             gnss_observables_iter->second,
-                                            beidou_ephemeris_iter->second.i_BEIDOU_week + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
+                                            beidou_ephemeris_iter->second.WN + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
                                             0);
                                         valid_obs++;
                                     }
@@ -757,9 +742,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                             {
                                                 if (eph_data[i].sat == (static_cast<int>(gnss_observables_iter->second.PRN + NSATGPS + NSATGLO + NSATGAL + NSATQZS)))
                                                     {
-                                                        obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(obs_data[i + glo_valid_obs],
+                                                        d_obs_data[i + glo_valid_obs] = insert_obs_to_rtklib(d_obs_data[i + glo_valid_obs],
                                                             gnss_observables_iter->second,
-                                                            beidou_ephemeris_iter->second.i_BEIDOU_week + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
+                                                            beidou_ephemeris_iter->second.WN + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
                                                             2);  // Band 3 (L2/G2/B3)
                                                         found_B1I_obs = true;
                                                         break;
@@ -775,9 +760,9 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                                 obsd_t newobs = {{0, 0}, '0', '0', {}, {},
                                                     {default_code_, default_code_, default_code_},
                                                     {}, {0.0, 0.0, 0.0}, {}};
-                                                obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
+                                                d_obs_data[valid_obs + glo_valid_obs] = insert_obs_to_rtklib(newobs,
                                                     gnss_observables_iter->second,
-                                                    beidou_ephemeris_iter->second.i_BEIDOU_week + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
+                                                    beidou_ephemeris_iter->second.WN + BEIDOU_DNAV_BDT2GPST_WEEK_NUM_OFFSET,
                                                     2);  // Band 2 (L2/G2)
                                                 valid_obs++;
                                             }
@@ -811,59 +796,59 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
             nav_data.ng = glo_valid_obs;
             if (gps_iono.valid)
                 {
-                    nav_data.ion_gps[0] = gps_iono.d_alpha0;
-                    nav_data.ion_gps[1] = gps_iono.d_alpha1;
-                    nav_data.ion_gps[2] = gps_iono.d_alpha2;
-                    nav_data.ion_gps[3] = gps_iono.d_alpha3;
-                    nav_data.ion_gps[4] = gps_iono.d_beta0;
-                    nav_data.ion_gps[5] = gps_iono.d_beta1;
-                    nav_data.ion_gps[6] = gps_iono.d_beta2;
-                    nav_data.ion_gps[7] = gps_iono.d_beta3;
+                    nav_data.ion_gps[0] = gps_iono.alpha0;
+                    nav_data.ion_gps[1] = gps_iono.alpha1;
+                    nav_data.ion_gps[2] = gps_iono.alpha2;
+                    nav_data.ion_gps[3] = gps_iono.alpha3;
+                    nav_data.ion_gps[4] = gps_iono.beta0;
+                    nav_data.ion_gps[5] = gps_iono.beta1;
+                    nav_data.ion_gps[6] = gps_iono.beta2;
+                    nav_data.ion_gps[7] = gps_iono.beta3;
                 }
             if (!(gps_iono.valid) and gps_cnav_iono.valid)
                 {
-                    nav_data.ion_gps[0] = gps_cnav_iono.d_alpha0;
-                    nav_data.ion_gps[1] = gps_cnav_iono.d_alpha1;
-                    nav_data.ion_gps[2] = gps_cnav_iono.d_alpha2;
-                    nav_data.ion_gps[3] = gps_cnav_iono.d_alpha3;
-                    nav_data.ion_gps[4] = gps_cnav_iono.d_beta0;
-                    nav_data.ion_gps[5] = gps_cnav_iono.d_beta1;
-                    nav_data.ion_gps[6] = gps_cnav_iono.d_beta2;
-                    nav_data.ion_gps[7] = gps_cnav_iono.d_beta3;
+                    nav_data.ion_gps[0] = gps_cnav_iono.alpha0;
+                    nav_data.ion_gps[1] = gps_cnav_iono.alpha1;
+                    nav_data.ion_gps[2] = gps_cnav_iono.alpha2;
+                    nav_data.ion_gps[3] = gps_cnav_iono.alpha3;
+                    nav_data.ion_gps[4] = gps_cnav_iono.beta0;
+                    nav_data.ion_gps[5] = gps_cnav_iono.beta1;
+                    nav_data.ion_gps[6] = gps_cnav_iono.beta2;
+                    nav_data.ion_gps[7] = gps_cnav_iono.beta3;
                 }
-            if (galileo_iono.ai0_5 != 0.0)
+            if (galileo_iono.ai0 != 0.0)
                 {
-                    nav_data.ion_gal[0] = galileo_iono.ai0_5;
-                    nav_data.ion_gal[1] = galileo_iono.ai1_5;
-                    nav_data.ion_gal[2] = galileo_iono.ai2_5;
+                    nav_data.ion_gal[0] = galileo_iono.ai0;
+                    nav_data.ion_gal[1] = galileo_iono.ai1;
+                    nav_data.ion_gal[2] = galileo_iono.ai2;
                     nav_data.ion_gal[3] = 0.0;
                 }
             if (beidou_dnav_iono.valid)
                 {
-                    nav_data.ion_cmp[0] = beidou_dnav_iono.d_alpha0;
-                    nav_data.ion_cmp[1] = beidou_dnav_iono.d_alpha1;
-                    nav_data.ion_cmp[2] = beidou_dnav_iono.d_alpha2;
-                    nav_data.ion_cmp[3] = beidou_dnav_iono.d_alpha3;
-                    nav_data.ion_cmp[4] = beidou_dnav_iono.d_beta0;
-                    nav_data.ion_cmp[5] = beidou_dnav_iono.d_beta0;
-                    nav_data.ion_cmp[6] = beidou_dnav_iono.d_beta0;
-                    nav_data.ion_cmp[7] = beidou_dnav_iono.d_beta3;
+                    nav_data.ion_cmp[0] = beidou_dnav_iono.alpha0;
+                    nav_data.ion_cmp[1] = beidou_dnav_iono.alpha1;
+                    nav_data.ion_cmp[2] = beidou_dnav_iono.alpha2;
+                    nav_data.ion_cmp[3] = beidou_dnav_iono.alpha3;
+                    nav_data.ion_cmp[4] = beidou_dnav_iono.beta0;
+                    nav_data.ion_cmp[5] = beidou_dnav_iono.beta0;
+                    nav_data.ion_cmp[6] = beidou_dnav_iono.beta0;
+                    nav_data.ion_cmp[7] = beidou_dnav_iono.beta3;
                 }
             if (gps_utc_model.valid)
                 {
-                    nav_data.utc_gps[0] = gps_utc_model.d_A0;
-                    nav_data.utc_gps[1] = gps_utc_model.d_A1;
-                    nav_data.utc_gps[2] = gps_utc_model.d_t_OT;
-                    nav_data.utc_gps[3] = gps_utc_model.i_WN_T;
-                    nav_data.leaps = gps_utc_model.d_DeltaT_LS;
+                    nav_data.utc_gps[0] = gps_utc_model.A0;
+                    nav_data.utc_gps[1] = gps_utc_model.A1;
+                    nav_data.utc_gps[2] = gps_utc_model.tot;
+                    nav_data.utc_gps[3] = gps_utc_model.WN_T;
+                    nav_data.leaps = gps_utc_model.DeltaT_LS;
                 }
             if (!(gps_utc_model.valid) and gps_cnav_utc_model.valid)
                 {
-                    nav_data.utc_gps[0] = gps_cnav_utc_model.d_A0;
-                    nav_data.utc_gps[1] = gps_cnav_utc_model.d_A1;
-                    nav_data.utc_gps[2] = gps_cnav_utc_model.d_t_OT;
-                    nav_data.utc_gps[3] = gps_cnav_utc_model.i_WN_T;
-                    nav_data.leaps = gps_cnav_utc_model.d_DeltaT_LS;
+                    nav_data.utc_gps[0] = gps_cnav_utc_model.A0;
+                    nav_data.utc_gps[1] = gps_cnav_utc_model.A1;
+                    nav_data.utc_gps[2] = gps_cnav_utc_model.tot;
+                    nav_data.utc_gps[3] = gps_cnav_utc_model.WN_T;
+                    nav_data.leaps = gps_cnav_utc_model.DeltaT_LS;
                 }
             if (glonass_gnav_utc_model.valid)
                 {
@@ -872,21 +857,21 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                     nav_data.utc_glo[2] = 0.0;                             // ??
                     nav_data.utc_glo[3] = 0.0;                             // ??
                 }
-            if (galileo_utc_model.A0_6 != 0.0)
+            if (galileo_utc_model.A0 != 0.0)
                 {
-                    nav_data.utc_gal[0] = galileo_utc_model.A0_6;
-                    nav_data.utc_gal[1] = galileo_utc_model.A1_6;
-                    nav_data.utc_gal[2] = galileo_utc_model.t0t_6;
-                    nav_data.utc_gal[3] = galileo_utc_model.WNot_6;
-                    nav_data.leaps = galileo_utc_model.Delta_tLS_6;
+                    nav_data.utc_gal[0] = galileo_utc_model.A0;
+                    nav_data.utc_gal[1] = galileo_utc_model.A1;
+                    nav_data.utc_gal[2] = galileo_utc_model.tot;
+                    nav_data.utc_gal[3] = galileo_utc_model.WNot;
+                    nav_data.leaps = galileo_utc_model.Delta_tLS;
                 }
             if (beidou_dnav_utc_model.valid)
                 {
-                    nav_data.utc_cmp[0] = beidou_dnav_utc_model.d_A0_UTC;
-                    nav_data.utc_cmp[1] = beidou_dnav_utc_model.d_A1_UTC;
+                    nav_data.utc_cmp[0] = beidou_dnav_utc_model.A0_UTC;
+                    nav_data.utc_cmp[1] = beidou_dnav_utc_model.A1_UTC;
                     nav_data.utc_cmp[2] = 0.0;  // ??
                     nav_data.utc_cmp[3] = 0.0;  // ??
-                    nav_data.leaps = beidou_dnav_utc_model.i_DeltaT_LS;
+                    nav_data.leaps = beidou_dnav_utc_model.DeltaT_LS;
                 }
 
             /* update carrier wave length using native function call in RTKlib */
@@ -894,38 +879,45 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                 {
                     for (int j = 0; j < NFREQ; j++)
                         {
-                            nav_data.lam[i][j] = satwavelen(i + 1, j, &nav_data);
+                            if (j == 2 && gal_e5_is_e5b)
+                                {
+                                    // frq = 4 corresponds to E5B in that function
+                                    nav_data.lam[i][j] = satwavelen(i + 1, 4, &nav_data);
+                                }
+                            else
+                                {
+                                    nav_data.lam[i][j] = satwavelen(i + 1, j, &nav_data);
+                                }
                         }
                 }
 
-            result = rtkpos(&rtk_, obs_data.data(), valid_obs + glo_valid_obs, &nav_data);
+            result = rtkpos(&d_rtk, d_obs_data.data(), valid_obs + glo_valid_obs, &nav_data);
 
             if (result == 0)
                 {
-                    LOG(INFO) << "RTKLIB rtkpos error: " << rtk_.errbuf;
-                    rtk_.neb = 0;                  // clear error buffer to avoid repeating the error message
+                    LOG(INFO) << "RTKLIB rtkpos error: " << d_rtk.errbuf;
+                    d_rtk.neb = 0;                 // clear error buffer to avoid repeating the error message
                     this->set_time_offset_s(0.0);  // reset rx time estimation
                     this->set_num_valid_observations(0);
                 }
             else
                 {
-                    this->set_num_valid_observations(rtk_.sol.ns);  // record the number of valid satellites used by the PVT solver
-                    pvt_sol = rtk_.sol;
+                    this->set_num_valid_observations(d_rtk.sol.ns);  // record the number of valid satellites used by the PVT solver
+                    pvt_sol = d_rtk.sol;
                     // DOP computation
                     unsigned int used_sats = 0;
                     for (unsigned int i = 0; i < MAXSAT; i++)
                         {
-                            pvt_ssat[i] = rtk_.ssat[i];
-                            if (rtk_.ssat[i].vs == 1)
+                            pvt_ssat[i] = d_rtk.ssat[i];
+                            if (d_rtk.ssat[i].vs == 1)
                                 {
                                     used_sats++;
                                 }
                         }
 
-                    std::vector<double> azel;
-                    azel.reserve(used_sats * 2);
+                    std::vector<double> azel(used_sats * 2);
                     int index_aux = 0;
-                    for (auto &i : rtk_.ssat)
+                    for (auto &i : d_rtk.ssat)
                         {
                             if (i.vs == 1)
                                 {
@@ -937,7 +929,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
 
                     if (index_aux > 0)
                         {
-                            dops(index_aux, azel.data(), 0.0, dop_.data());
+                            dops(index_aux, azel.data(), 0.0, d_dop.data());
                         }
                     this->set_valid_position(true);
                     std::array<double, 4> rx_position_and_time{};
@@ -945,7 +937,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                     rx_position_and_time[1] = pvt_sol.rr[1];  // [m]
                     rx_position_and_time[2] = pvt_sol.rr[2];  // [m]
                     // todo: fix this ambiguity in the RTKLIB units in receiver clock offset!
-                    if (rtk_.opt.mode == PMODE_SINGLE)
+                    if (d_rtk.opt.mode == PMODE_SINGLE)
                         {
                             // if the RTKLIB solver is set to SINGLE, the dtr is already expressed in [s]
                             // add also the clock offset from gps to galileo (pvt_sol.dtr[2])
@@ -998,53 +990,53 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
 
                     // ######## PVT MONITOR #########
                     // TOW
-                    monitor_pvt.TOW_at_current_symbol_ms = gnss_observables_map.cbegin()->second.TOW_at_current_symbol_ms;
+                    d_monitor_pvt.TOW_at_current_symbol_ms = gnss_observables_map.cbegin()->second.TOW_at_current_symbol_ms;
                     // WEEK
-                    monitor_pvt.week = adjgpsweek(nav_data.eph[0].week, this->is_pre_2009());
+                    d_monitor_pvt.week = adjgpsweek(nav_data.eph[0].week, this->is_pre_2009());
                     // PVT GPS time
-                    monitor_pvt.RX_time = gnss_observables_map.cbegin()->second.RX_time;
+                    d_monitor_pvt.RX_time = gnss_observables_map.cbegin()->second.RX_time;
                     // User clock offset [s]
-                    monitor_pvt.user_clk_offset = rx_position_and_time[3];
+                    d_monitor_pvt.user_clk_offset = rx_position_and_time[3];
 
                     // ECEF POS X,Y,X [m] + ECEF VEL X,Y,X [m/s] (6 x double)
-                    monitor_pvt.pos_x = pvt_sol.rr[0];
-                    monitor_pvt.pos_y = pvt_sol.rr[1];
-                    monitor_pvt.pos_z = pvt_sol.rr[2];
-                    monitor_pvt.vel_x = pvt_sol.rr[3];
-                    monitor_pvt.vel_y = pvt_sol.rr[4];
-                    monitor_pvt.vel_z = pvt_sol.rr[5];
+                    d_monitor_pvt.pos_x = pvt_sol.rr[0];
+                    d_monitor_pvt.pos_y = pvt_sol.rr[1];
+                    d_monitor_pvt.pos_z = pvt_sol.rr[2];
+                    d_monitor_pvt.vel_x = pvt_sol.rr[3];
+                    d_monitor_pvt.vel_y = pvt_sol.rr[4];
+                    d_monitor_pvt.vel_z = pvt_sol.rr[5];
 
                     // position variance/covariance (m^2) {c_xx,c_yy,c_zz,c_xy,c_yz,c_zx} (6 x double)
-                    monitor_pvt.cov_xx = pvt_sol.qr[0];
-                    monitor_pvt.cov_yy = pvt_sol.qr[1];
-                    monitor_pvt.cov_zz = pvt_sol.qr[2];
-                    monitor_pvt.cov_xy = pvt_sol.qr[3];
-                    monitor_pvt.cov_yz = pvt_sol.qr[4];
-                    monitor_pvt.cov_zx = pvt_sol.qr[5];
+                    d_monitor_pvt.cov_xx = pvt_sol.qr[0];
+                    d_monitor_pvt.cov_yy = pvt_sol.qr[1];
+                    d_monitor_pvt.cov_zz = pvt_sol.qr[2];
+                    d_monitor_pvt.cov_xy = pvt_sol.qr[3];
+                    d_monitor_pvt.cov_yz = pvt_sol.qr[4];
+                    d_monitor_pvt.cov_zx = pvt_sol.qr[5];
 
                     // GEO user position Latitude [deg]
-                    monitor_pvt.latitude = this->get_latitude();
+                    d_monitor_pvt.latitude = this->get_latitude();
                     // GEO user position Longitude [deg]
-                    monitor_pvt.longitude = this->get_longitude();
+                    d_monitor_pvt.longitude = this->get_longitude();
                     // GEO user position Height [m]
-                    monitor_pvt.height = this->get_height();
+                    d_monitor_pvt.height = this->get_height();
 
                     // NUMBER OF VALID SATS
-                    monitor_pvt.valid_sats = pvt_sol.ns;
+                    d_monitor_pvt.valid_sats = pvt_sol.ns;
                     // RTKLIB solution status
-                    monitor_pvt.solution_status = pvt_sol.stat;
+                    d_monitor_pvt.solution_status = pvt_sol.stat;
                     // RTKLIB solution type (0:xyz-ecef,1:enu-baseline)
-                    monitor_pvt.solution_type = pvt_sol.type;
+                    d_monitor_pvt.solution_type = pvt_sol.type;
                     // AR ratio factor for validation
-                    monitor_pvt.AR_ratio_factor = pvt_sol.ratio;
+                    d_monitor_pvt.AR_ratio_factor = pvt_sol.ratio;
                     // AR ratio threshold for validation
-                    monitor_pvt.AR_ratio_threshold = pvt_sol.thres;
+                    d_monitor_pvt.AR_ratio_threshold = pvt_sol.thres;
 
                     // GDOP / PDOP/ HDOP/ VDOP
-                    monitor_pvt.gdop = dop_[0];
-                    monitor_pvt.pdop = dop_[1];
-                    monitor_pvt.hdop = dop_[2];
-                    monitor_pvt.vdop = dop_[3];
+                    d_monitor_pvt.gdop = d_dop[0];
+                    d_monitor_pvt.pdop = d_dop[1];
+                    d_monitor_pvt.hdop = d_dop[2];
+                    d_monitor_pvt.vdop = d_dop[3];
 
                     this->set_rx_vel({enuv[0], enuv[1], enuv[2]});
 
@@ -1052,7 +1044,7 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
 
                     this->set_clock_drift_ppm(clock_drift_ppm);
                     // User clock drift [ppm]
-                    monitor_pvt.user_clk_drift_ppm = clock_drift_ppm;
+                    d_monitor_pvt.user_clk_drift_ppm = clock_drift_ppm;
 
                     // ######## LOG FILE #########
                     if (d_flag_dump_enabled == true)
@@ -1124,11 +1116,11 @@ bool Rtklib_Solver::get_PVT(const std::map<int, Gnss_Synchro> &gnss_observables_
                                     // AR ratio threshold for validation
                                     d_dump_file.write(reinterpret_cast<char *>(&pvt_sol.thres), sizeof(float));
 
-                                    // GDOP / PDOP/ HDOP/ VDOP
-                                    d_dump_file.write(reinterpret_cast<char *>(&dop_[0]), sizeof(double));
-                                    d_dump_file.write(reinterpret_cast<char *>(&dop_[1]), sizeof(double));
-                                    d_dump_file.write(reinterpret_cast<char *>(&dop_[2]), sizeof(double));
-                                    d_dump_file.write(reinterpret_cast<char *>(&dop_[3]), sizeof(double));
+                                    // GDOP / PDOP / HDOP / VDOP
+                                    d_dump_file.write(reinterpret_cast<char *>(&d_dop[0]), sizeof(double));
+                                    d_dump_file.write(reinterpret_cast<char *>(&d_dop[1]), sizeof(double));
+                                    d_dump_file.write(reinterpret_cast<char *>(&d_dop[2]), sizeof(double));
+                                    d_dump_file.write(reinterpret_cast<char *>(&d_dop[3]), sizeof(double));
                                 }
                             catch (const std::ifstream::failure &e)
                                 {
