@@ -362,9 +362,8 @@ static Node* GetCacheTypeString(CacheType cache_type)
             return CreateConstantString("stlb");
         case CPU_FEATURE_CACHE_PREFETCH:
             return CreateConstantString("prefetch");
-        default:
-            return CreateConstantString("null");
         }
+    UNREACHABLE();
 }
 
 static void AddCacheInfo(Node* root, const CacheInfo* cache_info)
