@@ -19,8 +19,8 @@
 #define GNSS_SDR_CUSTOM_UDP_SIGNAL_SOURCE_H
 
 #include "concurrent_queue.h"
-#include "gnss_block_interface.h"
 #include "gr_complex_ip_packet_source.h"
+#include "signal_source_base.h"
 #include <gnuradio/blocks/file_sink.h>
 #include <gnuradio/blocks/null_sink.h>
 #include <pmt/pmt.h>
@@ -40,7 +40,7 @@ class ConfigurationInterface;
  * \brief This class reads from UDP packets, which streams interleaved
  * I/Q samples over a network.
  */
-class CustomUDPSignalSource : public GNSSBlockInterface
+class CustomUDPSignalSource : public SignalSourceBase
 {
 public:
     CustomUDPSignalSource(const ConfigurationInterface* configuration,
@@ -49,19 +49,6 @@ public:
 
     ~CustomUDPSignalSource() = default;
 
-    inline std::string role() override
-    {
-        return role_;
-    }
-
-    /*!
-     * \brief Returns "Custom_UDP_Signal_Source"
-     */
-    inline std::string implementation() override
-    {
-        return "Custom_UDP_Signal_Source";
-    }
-
     inline size_t item_size() override
     {
         return item_size_;
@@ -78,7 +65,6 @@ private:
     std::vector<gnss_shared_ptr<gr::block>> null_sinks_;
     std::vector<gnss_shared_ptr<gr::block>> file_sink_;
 
-    std::string role_;
     std::string item_type_;
     std::string dump_filename_;
 
