@@ -11,13 +11,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -26,7 +23,7 @@
 #include "glonass_l2_ca_dll_pll_c_aid_tracking_cc.h"
 #include "GLONASS_L1_L2_CA.h"
 #include "MATH_CONSTANTS.h"
-#include "glonass_l2_signal_processing.h"
+#include "glonass_l2_signal_replica.h"
 #include "gnss_satellite.h"
 #include "gnss_sdr_flags.h"
 #include "lock_detectors.h"
@@ -38,6 +35,7 @@
 #include <algorithm>
 #include <array>
 #include <cmath>
+#include <cstddef>
 #include <exception>
 #include <iostream>
 #include <memory>
@@ -103,8 +101,56 @@ glonass_l2_ca_dll_pll_c_aid_tracking_cc::glonass_l2_ca_dll_pll_c_aid_tracking_cc
     float pll_bw_narrow_hz,
     float dll_bw_narrow_hz,
     int32_t extend_correlation_ms,
-    float early_late_space_chips) : gr::block("glonass_l2_ca_dll_pll_c_aid_tracking_cc", gr::io_signature::make(1, 1, sizeof(gr_complex)),
-                                        gr::io_signature::make(1, 1, sizeof(Gnss_Synchro)))
+    float early_late_space_chips)
+    : gr::block("glonass_l2_ca_dll_pll_c_aid_tracking_cc", gr::io_signature::make(1, 1, sizeof(gr_complex)),
+          gr::io_signature::make(1, 1, sizeof(Gnss_Synchro))),
+      d_dump_filename(dump_filename),
+      d_acquisition_gnss_synchro(nullptr),
+      d_fs_in(fs_in),
+      d_glonass_freq_ch(0),
+      d_early_late_spc_chips(early_late_space_chips),
+      d_vector_length(vector_length),
+      d_channel(0),
+      d_n_correlator_taps(3),
+      d_rem_code_phase_samples(0.0),
+      d_rem_code_phase_chips(0.0),
+      d_rem_carrier_phase_rad(0.0),
+      d_rem_code_phase_integer_samples(0),
+      d_acq_code_phase_samples(0.0),
+      d_acq_carrier_doppler_hz(0.0),
+      d_dll_bw_hz(dll_bw_hz),
+      d_pll_bw_hz(pll_bw_hz),
+      d_dll_bw_narrow_hz(dll_bw_narrow_hz),
+      d_pll_bw_narrow_hz(pll_bw_narrow_hz),
+      d_code_freq_chips(GLONASS_L2_CA_CODE_RATE_CPS),
+      d_code_phase_step_chips(0.0),
+      d_carrier_doppler_hz(0.0),
+      d_carrier_frequency_hz(0.0),
+      d_carrier_doppler_old_hz(0.0),
+      d_carrier_phase_step_rad(0.0),
+      d_acc_carrier_phase_cycles(0.0),
+      d_code_phase_samples(0.0),
+      d_pll_to_dll_assist_secs_Ti(0.0),
+      d_code_error_chips_Ti(0.0),
+      d_code_error_filt_chips_s(0.0),
+      d_code_error_filt_chips_Ti(0.0),
+      d_carr_phase_error_secs_Ti(0.0),
+      d_preamble_timestamp_s(0.0),
+      d_extend_correlation_ms(extend_correlation_ms),
+      d_correlation_length_samples(static_cast<int32_t>(d_vector_length)),
+      d_sample_counter(0ULL),
+      d_acq_sample_stamp(0),
+      d_cn0_estimation_counter(0),
+      d_carrier_lock_test(1),
+      d_CN0_SNV_dB_Hz(0),
+      d_carrier_lock_threshold(FLAGS_carrier_lock_th),
+      d_carrier_lock_fail_counter(0),
+      d_enable_extended_integration(false),
+      d_preamble_synchronized(false),
+      d_enable_tracking(false),
+      d_pull_in(false),
+      d_acc_carrier_phase_initialized(false),
+      d_dump(dump)
 {
     // Telemetry bit synchronization message port input
     this->message_port_register_in(pmt::mp("preamble_timestamp_s"));
@@ -121,34 +167,17 @@ glonass_l2_ca_dll_pll_c_aid_tracking_cc::glonass_l2_ca_dll_pll_c_aid_tracking_cc
 #endif
     this->message_port_register_out(pmt::mp("events"));
     this->message_port_register_in(pmt::mp("telemetry_to_trk"));
-    // initialize internal vars
-    d_dump = dump;
-    d_fs_in = fs_in;
-    d_vector_length = vector_length;
-    d_dump_filename = dump_filename;
-    d_correlation_length_samples = static_cast<int32_t>(d_vector_length);
 
-    // Initialize tracking  ==========================================
-    d_pll_bw_hz = pll_bw_hz;
-    d_dll_bw_hz = dll_bw_hz;
-    d_pll_bw_narrow_hz = pll_bw_narrow_hz;
-    d_dll_bw_narrow_hz = dll_bw_narrow_hz;
-    d_extend_correlation_ms = extend_correlation_ms;
     d_code_loop_filter.set_DLL_BW(d_dll_bw_hz);
     d_carrier_loop_filter.set_params(10.0, d_pll_bw_hz, 2);
 
-    // --- DLL variables --------------------------------------------------------
-    d_early_late_spc_chips = early_late_space_chips;  // Define early-late offset (in chips)
-
     // Initialization of local code replica
     // Get space for a vector with the C/A code replica sampled 1x/chip
-    d_ca_code.resize(static_cast<int32_t>(GLONASS_L2_CA_CODE_LENGTH_CHIPS), gr_complex(0.0, 0.0));
+    d_ca_code = volk_gnsssdr::vector<gr_complex>(static_cast<size_t>(GLONASS_L2_CA_CODE_LENGTH_CHIPS));
 
-    // correlator outputs (scalar)
-    d_n_correlator_taps = 3;  // Early, Prompt, and Late
-    d_correlator_outs.resize(d_n_correlator_taps, gr_complex(0.0, 0.0));
+    d_correlator_outs = volk_gnsssdr::vector<gr_complex>(d_n_correlator_taps);
 
-    d_local_code_shift_chips.reserve(d_n_correlator_taps);
+    d_local_code_shift_chips = volk_gnsssdr::vector<float>(d_n_correlator_taps);
     // Set TAPs delay values [chips]
     d_local_code_shift_chips[0] = -d_early_late_spc_chips;
     d_local_code_shift_chips[1] = 0.0;
@@ -156,59 +185,11 @@ glonass_l2_ca_dll_pll_c_aid_tracking_cc::glonass_l2_ca_dll_pll_c_aid_tracking_cc
 
     multicorrelator_cpu.init(2 * d_correlation_length_samples, d_n_correlator_taps);
 
-    // --- Perform initializations ------------------------------
-    // define initial code frequency basis of NCO
-    d_code_freq_chips = GLONASS_L2_CA_CODE_RATE_CPS;
-    // define residual code phase (in chips)
-    d_rem_code_phase_samples = 0.0;
-    // define residual carrier phase
-    d_rem_carrier_phase_rad = 0.0;
-
-    // sample synchronization
-    d_sample_counter = 0ULL;  // (from trk to tlm)
-    d_acq_sample_stamp = 0;
-    d_enable_tracking = false;
-    d_pull_in = false;
-
-    // CN0 estimation and lock detector buffers
-    d_cn0_estimation_counter = 0;
-    d_Prompt_buffer.reserve(FLAGS_cn0_samples);
-    d_carrier_lock_test = 1;
-    d_CN0_SNV_dB_Hz = 0;
-    d_carrier_lock_fail_counter = 0;
-    d_carrier_lock_threshold = FLAGS_carrier_lock_th;
+    d_Prompt_buffer = volk_gnsssdr::vector<gr_complex>(FLAGS_cn0_samples);
 
     systemName["R"] = std::string("Glonass");
 
     set_relative_rate(1.0 / static_cast<double>(d_vector_length));
-
-    d_acquisition_gnss_synchro = nullptr;
-    d_channel = 0;
-    d_acq_code_phase_samples = 0.0;
-    d_acq_carrier_doppler_hz = 0.0;
-    d_carrier_doppler_hz = 0.0;
-    d_code_error_filt_chips_Ti = 0.0;
-    d_acc_carrier_phase_cycles = 0.0;
-    d_code_phase_samples = 0.0;
-
-    d_pll_to_dll_assist_secs_Ti = 0.0;
-    d_rem_code_phase_chips = 0.0;
-    d_code_phase_step_chips = 0.0;
-    d_carrier_phase_step_rad = 0.0;
-    d_enable_extended_integration = false;
-    d_preamble_synchronized = false;
-    d_rem_code_phase_integer_samples = 0;
-    d_code_error_chips_Ti = 0.0;
-    d_code_error_filt_chips_s = 0.0;
-    d_carr_phase_error_secs_Ti = 0.0;
-    d_preamble_timestamp_s = 0.0;
-
-    d_carrier_frequency_hz = 0.0;
-    d_carrier_doppler_old_hz = 0.0;
-
-    d_glonass_freq_ch = 0;
-
-    d_acc_carrier_phase_initialized = false;
     // set_min_output_buffer((int64_t)300);
 }
 
@@ -571,6 +552,7 @@ int glonass_l2_ca_dll_pll_c_aid_tracking_cc::general_work(int noutput_items __at
     double code_error_filt_secs_Ti = 0.0;
     double CURRENT_INTEGRATION_TIME_S = 0.0;
     double CORRECTED_INTEGRATION_TIME_S = 0.0;
+    bool loss_of_lock = false;
 
     if (d_enable_tracking == true)
         {
@@ -779,6 +761,7 @@ int glonass_l2_ca_dll_pll_c_aid_tracking_cc::general_work(int noutput_items __at
                                     this->message_port_pub(pmt::mp("events"), pmt::from_long(3));  // 3 -> loss of lock
                                     d_carrier_lock_fail_counter = 0;
                                     d_enable_tracking = false;  // TODO: check if disabling tracking is consistent with the channel state machine
+                                    loss_of_lock = true;
                                 }
                             check_carrier_phase_coherent_initialization();
                         }
@@ -790,7 +773,7 @@ int glonass_l2_ca_dll_pll_c_aid_tracking_cc::general_work(int noutput_items __at
                     current_synchro_data.Carrier_phase_rads = TWO_PI * d_acc_carrier_phase_cycles;
                     current_synchro_data.Carrier_Doppler_hz = d_carrier_doppler_hz;
                     current_synchro_data.CN0_dB_hz = d_CN0_SNV_dB_Hz;
-                    current_synchro_data.Flag_valid_symbol_output = true;
+                    current_synchro_data.Flag_valid_symbol_output = !loss_of_lock;
                     if (d_preamble_synchronized == true)
                         {
                             current_synchro_data.correlation_length_ms = d_extend_correlation_ms;
