@@ -6,53 +6,39 @@
  * TODO: put here supl.c author info
  * class that implements a C++ interface to external Secure User Location Protocol (SUPL) client library.
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "gnss_sdr_supl_client.h"
+#include "GPS_L1_CA.h"
+#include <boost/archive/xml_iarchive.hpp>
+#include <boost/archive/xml_oarchive.hpp>
+#include <boost/serialization/map.hpp>
+#include <glog/logging.h>
 #include <pugixml.hpp>
-#include <cmath>
-#include <utility>
+#include <cmath>      // for pow
+#include <exception>  // for exception
+#include <iostream>   // for cerr
+#include <utility>    // for pair
+#include <vector>
 
-gnss_sdr_supl_client::gnss_sdr_supl_client()
+Gnss_Sdr_Supl_Client::Gnss_Sdr_Supl_Client()
+    : server_port(0), request(0), mcc(0), mns(0), lac(0), ci(0)
 {
-    mcc = 0;
-    mns = 0;
-    lac = 0;
-    ci = 0;
     supl_ctx_new(&ctx);
     assist = supl_assist_t();
-    server_port = 0;
-    request = 0;
 }
 
 
-gnss_sdr_supl_client::~gnss_sdr_supl_client() = default;
-
-
-void gnss_sdr_supl_client::print_assistance()
+void Gnss_Sdr_Supl_Client::print_assistance()
 {
     if (assist.set & SUPL_RRLP_ASSIST_REFTIME)
         {
@@ -151,7 +137,7 @@ void gnss_sdr_supl_client::print_assistance()
 }
 
 
-int gnss_sdr_supl_client::get_assistance(int i_mcc, int i_mns, int i_lac, int i_ci)
+int Gnss_Sdr_Supl_Client::get_assistance(int i_mcc, int i_mns, int i_lac, int i_ci)
 {
     // SET SUPL CLIENT INFORMATION
     // GSM CELL PARAMETERS
@@ -165,14 +151,16 @@ int gnss_sdr_supl_client::get_assistance(int i_mcc, int i_mns, int i_lac, int i_
     supl_set_gsm_cell(&ctx, mcc, mns, lac, ci);
 
     // PERFORM SUPL COMMUNICATION
-    char* cstr = new char[server_name.length() + 1];
-    strcpy(cstr, server_name.c_str());
+    std::vector<char> cstr(server_name.length() + 1);
+    for (unsigned int i = 0; i != server_name.length(); ++i)
+        {
+            cstr[i] = static_cast<char>(server_name[i]);
+        }
 
     int err;
     ctx.p.request = request;  // select assistance info request from a pre-defined set
 
-    //std::cout<<"mcc="<<mcc<<"mns="<<mns<<"lac="<<lac<<"ci="<<ci<<std::endl;
-    err = supl_get_assist(&ctx, cstr, &assist);
+    err = supl_get_assist(&ctx, cstr.data(), &assist);
     if (err == 0)
         {
             read_supl_data();
@@ -183,17 +171,16 @@ int gnss_sdr_supl_client::get_assistance(int i_mcc, int i_mns, int i_lac, int i_
     else
         {
             /*
-	   * If supl_get_assist() fails, the connection remains open
-	   * and the memory/files are not released.
-	   */
+             * If supl_get_assist() fails, the connection remains open
+             * and the memory/files are not released.
+             */
             supl_close(&ctx);
         }
-    delete[] cstr;
     return err;
 }
 
 
-void gnss_sdr_supl_client::read_supl_data()
+void Gnss_Sdr_Supl_Client::read_supl_data()
 {
     // READ REFERENCE LOCATION
     if (assist.set & SUPL_RRLP_ASSIST_REFLOC)
@@ -208,39 +195,39 @@ void gnss_sdr_supl_client::read_supl_data()
     if (assist.set & SUPL_RRLP_ASSIST_REFTIME)
         {
             /* TS 44.031: GPSTOW, range 0-604799.92, resolution 0.08 sec, 23-bit presentation */
-            gps_time.d_TOW = static_cast<double>(assist.time.gps_tow) * 0.08;
-            gps_time.d_Week = static_cast<double>(assist.time.gps_week);
-            gps_time.d_tv_sec = static_cast<double>(assist.time.stamp.tv_sec);
-            gps_time.d_tv_usec = static_cast<double>(assist.time.stamp.tv_usec);
+            gps_time.tow = static_cast<double>(assist.time.gps_tow) * 0.08;
+            gps_time.week = static_cast<double>(assist.time.gps_week);
+            gps_time.seconds = static_cast<double>(assist.time.stamp.tv_sec);
+            gps_time.microseconds = static_cast<double>(assist.time.stamp.tv_usec);
             gps_time.valid = true;
         }
 
     // READ UTC MODEL
     if (assist.set & SUPL_RRLP_ASSIST_UTC)
         {
-            gps_utc.d_A0 = static_cast<double>(assist.utc.a0) * pow(2.0, -30);
-            gps_utc.d_A1 = static_cast<double>(assist.utc.a1) * pow(2.0, -50);
-            gps_utc.d_DeltaT_LS = static_cast<int32_t>(assist.utc.delta_tls);
-            gps_utc.d_DeltaT_LSF = static_cast<int32_t>(assist.utc.delta_tlsf);
-            gps_utc.d_t_OT = static_cast<int32_t>(assist.utc.tot) * pow(2.0, 12);
-            gps_utc.i_DN = static_cast<int32_t>(assist.utc.dn);
-            gps_utc.i_WN_T = static_cast<int32_t>(assist.utc.wnt);
-            gps_utc.i_WN_LSF = static_cast<int32_t>(assist.utc.wnlsf);
+            gps_utc.A0 = static_cast<double>(assist.utc.a0) * pow(2.0, -30);
+            gps_utc.A1 = static_cast<double>(assist.utc.a1) * pow(2.0, -50);
+            gps_utc.DeltaT_LS = static_cast<int32_t>(assist.utc.delta_tls);
+            gps_utc.DeltaT_LSF = static_cast<int32_t>(assist.utc.delta_tlsf);
+            gps_utc.tot = static_cast<int32_t>(assist.utc.tot) * pow(2.0, 12);
+            gps_utc.DN = static_cast<int32_t>(assist.utc.dn);
+            gps_utc.WN_T = static_cast<int32_t>(assist.utc.wnt);
+            gps_utc.WN_LSF = static_cast<int32_t>(assist.utc.wnlsf);
             gps_utc.valid = true;
         }
 
     // READ IONOSPHERIC MODEL
     if (assist.set & SUPL_RRLP_ASSIST_IONO)
         {
-            gps_iono.d_alpha0 = static_cast<double>(assist.iono.a0) * ALPHA_0_LSB;
-            gps_iono.d_alpha1 = static_cast<double>(assist.iono.a1) * ALPHA_1_LSB;
-            gps_iono.d_alpha2 = static_cast<double>(assist.iono.a2) * ALPHA_2_LSB;
-            gps_iono.d_alpha3 = static_cast<double>(assist.iono.a3) * ALPHA_3_LSB;
+            gps_iono.alpha0 = static_cast<double>(assist.iono.a0) * ALPHA_0_LSB;
+            gps_iono.alpha1 = static_cast<double>(assist.iono.a1) * ALPHA_1_LSB;
+            gps_iono.alpha2 = static_cast<double>(assist.iono.a2) * ALPHA_2_LSB;
+            gps_iono.alpha3 = static_cast<double>(assist.iono.a3) * ALPHA_3_LSB;
 
-            gps_iono.d_beta0 = static_cast<double>(assist.iono.b0) * BETA_0_LSB;
-            gps_iono.d_beta1 = static_cast<double>(assist.iono.b1) * BETA_1_LSB;
-            gps_iono.d_beta2 = static_cast<double>(assist.iono.b2) * BETA_2_LSB;
-            gps_iono.d_beta3 = static_cast<double>(assist.iono.b3) * BETA_3_LSB;
+            gps_iono.beta0 = static_cast<double>(assist.iono.b0) * BETA_0_LSB;
+            gps_iono.beta1 = static_cast<double>(assist.iono.b1) * BETA_1_LSB;
+            gps_iono.beta2 = static_cast<double>(assist.iono.b2) * BETA_2_LSB;
+            gps_iono.beta3 = static_cast<double>(assist.iono.b3) * BETA_3_LSB;
             gps_iono.valid = true;
         }
 
@@ -260,17 +247,17 @@ void gnss_sdr_supl_client::read_supl_data()
                             gps_almanac_map.insert(std::pair<int, Gps_Almanac>(a->prn, gps_almanac_entry));
                             gps_almanac_iterator = this->gps_almanac_map.find(a->prn);
                         }
-                    gps_almanac_iterator->second.i_satellite_PRN = a->prn;
-                    gps_almanac_iterator->second.d_A_f0 = static_cast<double>(a->AF0) * pow(2.0, -20);
-                    gps_almanac_iterator->second.d_A_f1 = static_cast<double>(a->AF1) * pow(2.0, -38);
-                    gps_almanac_iterator->second.d_Delta_i = static_cast<double>(a->Ksii) * pow(2.0, -19);
-                    gps_almanac_iterator->second.d_OMEGA = static_cast<double>(a->w) * pow(2.0, -23);
-                    gps_almanac_iterator->second.d_OMEGA0 = static_cast<double>(a->OMEGA_0) * pow(2.0, -23);
-                    gps_almanac_iterator->second.d_sqrt_A = static_cast<double>(a->A_sqrt) * pow(2.0, -11);
-                    gps_almanac_iterator->second.d_OMEGA_DOT = static_cast<double>(a->OMEGA_dot) * pow(2.0, -38);
-                    gps_almanac_iterator->second.i_Toa = static_cast<int32_t>(a->toa * pow(2.0, 12));
-                    gps_almanac_iterator->second.d_e_eccentricity = static_cast<double>(a->e) * pow(2.0, -21);
-                    gps_almanac_iterator->second.d_M_0 = static_cast<double>(a->M0) * pow(2.0, -23);
+                    gps_almanac_iterator->second.PRN = a->prn;
+                    gps_almanac_iterator->second.af0 = static_cast<double>(a->AF0) * pow(2.0, -20);
+                    gps_almanac_iterator->second.af1 = static_cast<double>(a->AF1) * pow(2.0, -38);
+                    gps_almanac_iterator->second.delta_i = static_cast<double>(a->Ksii) * pow(2.0, -19);
+                    gps_almanac_iterator->second.omega = static_cast<double>(a->w) * pow(2.0, -23);
+                    gps_almanac_iterator->second.OMEGA_0 = static_cast<double>(a->OMEGA_0) * pow(2.0, -23);
+                    gps_almanac_iterator->second.sqrtA = static_cast<double>(a->A_sqrt) * pow(2.0, -11);
+                    gps_almanac_iterator->second.OMEGAdot = static_cast<double>(a->OMEGA_dot) * pow(2.0, -38);
+                    gps_almanac_iterator->second.toa = static_cast<int32_t>(a->toa * pow(2.0, 12));
+                    gps_almanac_iterator->second.ecc = static_cast<double>(a->e) * pow(2.0, -21);
+                    gps_almanac_iterator->second.M_0 = static_cast<double>(a->M0) * pow(2.0, -23);
                 }
         }
 
@@ -292,46 +279,46 @@ void gnss_sdr_supl_client::read_supl_data()
                         }
                     if (gps_time.valid)
                         {
-                            gps_eph_iterator->second.i_GPS_week = assist.time.gps_week;
+                            gps_eph_iterator->second.WN = assist.time.gps_week;
                             /* TS 44.031: GPSTOW, range 0-604799.92, resolution 0.08 sec, 23-bit presentation */
-                            gps_eph_iterator->second.d_TOW = static_cast<double>(assist.time.gps_tow) * 0.08;
+                            gps_eph_iterator->second.tow = static_cast<double>(assist.time.gps_tow) * 0.08;
                         }
                     else
                         {
-                            gps_eph_iterator->second.i_GPS_week = 0;
-                            gps_eph_iterator->second.d_TOW = 0;
+                            gps_eph_iterator->second.WN = 0;
+                            gps_eph_iterator->second.tow = 0;
                         }
-                    gps_eph_iterator->second.i_satellite_PRN = e->prn;
+                    gps_eph_iterator->second.PRN = e->prn;
                     // SV navigation model
-                    gps_eph_iterator->second.i_code_on_L2 = e->bits;
-                    gps_eph_iterator->second.i_SV_accuracy = e->ura;  //User Range Accuracy (URA)
-                    gps_eph_iterator->second.i_SV_health = e->health;
-                    gps_eph_iterator->second.d_IODC = static_cast<double>(e->IODC);
-                    //miss P flag (1 bit)
-                    //miss SF1 Reserved (87 bits)
-                    gps_eph_iterator->second.d_TGD = static_cast<double>(e->tgd) * T_GD_LSB;
-                    gps_eph_iterator->second.d_Toc = static_cast<double>(e->toc) * T_OC_LSB;
-                    gps_eph_iterator->second.d_A_f0 = static_cast<double>(e->AF0) * A_F0_LSB;
-                    gps_eph_iterator->second.d_A_f1 = static_cast<double>(e->AF1) * A_F1_LSB;
-                    gps_eph_iterator->second.d_A_f2 = static_cast<double>(e->AF2) * A_F2_LSB;
-                    gps_eph_iterator->second.d_Crc = static_cast<double>(e->Crc) * C_RC_LSB;
-                    gps_eph_iterator->second.d_Delta_n = static_cast<double>(e->delta_n) * DELTA_N_LSB;
-                    gps_eph_iterator->second.d_M_0 = static_cast<double>(e->M0) * M_0_LSB;
-                    gps_eph_iterator->second.d_Cuc = static_cast<double>(e->Cuc) * C_UC_LSB;
-                    gps_eph_iterator->second.d_e_eccentricity = static_cast<double>(e->e) * E_LSB;
-                    gps_eph_iterator->second.d_Cus = static_cast<double>(e->Cus) * C_US_LSB;
-                    gps_eph_iterator->second.d_sqrt_A = static_cast<double>(e->A_sqrt) * SQRT_A_LSB;
-                    gps_eph_iterator->second.d_Toe = static_cast<double>(e->toe) * T_OE_LSB;
-                    //miss fit interval flag (1 bit)
-                    gps_eph_iterator->second.i_AODO = e->AODA * AODO_LSB;
-                    gps_eph_iterator->second.d_Cic = static_cast<double>(e->Cic) * C_IC_LSB;
-                    gps_eph_iterator->second.d_OMEGA0 = static_cast<double>(e->OMEGA_0) * OMEGA_0_LSB;
-                    gps_eph_iterator->second.d_Cis = static_cast<double>(e->Cis) * C_IS_LSB;
-                    gps_eph_iterator->second.d_i_0 = static_cast<double>(e->i0) * I_0_LSB;
-                    gps_eph_iterator->second.d_Crs = static_cast<double>(e->Crs) * C_RS_LSB;
-                    gps_eph_iterator->second.d_OMEGA = static_cast<double>(e->w) * OMEGA_LSB;
-                    gps_eph_iterator->second.d_OMEGA_DOT = static_cast<double>(e->OMEGA_dot) * OMEGA_DOT_LSB;
-                    gps_eph_iterator->second.d_IDOT = static_cast<double>(e->i_dot) * I_DOT_LSB;
+                    gps_eph_iterator->second.code_on_L2 = e->bits;
+                    gps_eph_iterator->second.SV_accuracy = e->ura;  // User Range Accuracy (URA)
+                    gps_eph_iterator->second.SV_health = e->health;
+                    gps_eph_iterator->second.IODC = static_cast<double>(e->IODC);
+                    // miss P flag (1 bit)
+                    // miss SF1 Reserved (87 bits)
+                    gps_eph_iterator->second.TGD = static_cast<double>(e->tgd) * T_GD_LSB;
+                    gps_eph_iterator->second.toc = static_cast<double>(e->toc) * T_OC_LSB;
+                    gps_eph_iterator->second.af0 = static_cast<double>(e->AF0) * A_F0_LSB;
+                    gps_eph_iterator->second.af1 = static_cast<double>(e->AF1) * A_F1_LSB;
+                    gps_eph_iterator->second.af2 = static_cast<double>(e->AF2) * A_F2_LSB;
+                    gps_eph_iterator->second.Crc = static_cast<double>(e->Crc) * C_RC_LSB;
+                    gps_eph_iterator->second.delta_n = static_cast<double>(e->delta_n) * DELTA_N_LSB;
+                    gps_eph_iterator->second.M_0 = static_cast<double>(e->M0) * M_0_LSB;
+                    gps_eph_iterator->second.Cuc = static_cast<double>(e->Cuc) * C_UC_LSB;
+                    gps_eph_iterator->second.ecc = static_cast<double>(e->e) * ECCENTRICITY_LSB;
+                    gps_eph_iterator->second.Cus = static_cast<double>(e->Cus) * C_US_LSB;
+                    gps_eph_iterator->second.sqrtA = static_cast<double>(e->A_sqrt) * SQRT_A_LSB;
+                    gps_eph_iterator->second.toe = static_cast<double>(e->toe) * T_OE_LSB;
+                    // miss fit interval flag (1 bit)
+                    gps_eph_iterator->second.AODO = e->AODA * AODO_LSB;
+                    gps_eph_iterator->second.Cic = static_cast<double>(e->Cic) * C_IC_LSB;
+                    gps_eph_iterator->second.OMEGA_0 = static_cast<double>(e->OMEGA_0) * OMEGA_0_LSB;
+                    gps_eph_iterator->second.Cis = static_cast<double>(e->Cis) * C_IS_LSB;
+                    gps_eph_iterator->second.i_0 = static_cast<double>(e->i0) * I_0_LSB;
+                    gps_eph_iterator->second.Crs = static_cast<double>(e->Crs) * C_RS_LSB;
+                    gps_eph_iterator->second.omega = static_cast<double>(e->w) * OMEGA_LSB;
+                    gps_eph_iterator->second.OMEGAdot = static_cast<double>(e->OMEGA_dot) * OMEGA_DOT_LSB;
+                    gps_eph_iterator->second.idot = static_cast<double>(e->i_dot) * I_DOT_LSB;
                 }
         }
 
@@ -353,10 +340,10 @@ void gnss_sdr_supl_client::read_supl_data()
                             gps_acq_iterator = this->gps_acq_map.find(e->prn);
                         }
                     // fill the acquisition assistance structure
-                    gps_acq_iterator->second.i_satellite_PRN = e->prn;
-                    gps_acq_iterator->second.d_TOW = static_cast<double>(assist.acq_time);
-                    gps_acq_iterator->second.d_Doppler0 = static_cast<double>(e->doppler0);
-                    gps_acq_iterator->second.d_Doppler1 = static_cast<double>(e->doppler1);
+                    gps_acq_iterator->second.PRN = e->prn;
+                    gps_acq_iterator->second.tow = static_cast<double>(assist.acq_time);
+                    gps_acq_iterator->second.Doppler0 = static_cast<double>(e->doppler0);
+                    gps_acq_iterator->second.Doppler1 = static_cast<double>(e->doppler1);
                     gps_acq_iterator->second.dopplerUncertainty = static_cast<double>(e->d_win);
                     gps_acq_iterator->second.Code_Phase = static_cast<double>(e->code_ph);
                     gps_acq_iterator->second.Code_Phase_int = static_cast<double>(e->code_ph_int);
@@ -369,7 +356,7 @@ void gnss_sdr_supl_client::read_supl_data()
 }
 
 
-bool gnss_sdr_supl_client::load_ephemeris_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_ephemeris_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -389,7 +376,7 @@ bool gnss_sdr_supl_client::load_ephemeris_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_ephemeris_map_xml(const std::string& file_name, std::map<int, Gps_Ephemeris> eph_map)
+bool Gnss_Sdr_Supl_Client::save_ephemeris_map_xml(const std::string& file_name, std::map<int, Gps_Ephemeris> eph_map)
 {
     if (eph_map.empty() == false)
         {
@@ -416,7 +403,7 @@ bool gnss_sdr_supl_client::save_ephemeris_map_xml(const std::string& file_name,
 }
 
 
-bool gnss_sdr_supl_client::load_gal_ephemeris_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gal_ephemeris_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -463,7 +450,7 @@ bool save_gal_ephemeris_map_xml(const std::string& file_name, std::map<int, Gali
 }
 
 
-bool gnss_sdr_supl_client::load_cnav_ephemeris_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_cnav_ephemeris_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -510,7 +497,7 @@ bool save_cnav_ephemeris_map_xml(const std::string& file_name, std::map<int, Gps
 }
 
 
-bool gnss_sdr_supl_client::load_gnav_ephemeris_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gnav_ephemeris_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -557,7 +544,7 @@ bool save_gnav_ephemeris_map_xml(const std::string& file_name, std::map<int, Glo
 }
 
 
-bool gnss_sdr_supl_client::load_utc_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_utc_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -576,7 +563,7 @@ bool gnss_sdr_supl_client::load_utc_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_utc_xml(const std::string& file_name, Gps_Utc_Model& utc)
+bool Gnss_Sdr_Supl_Client::save_utc_xml(const std::string& file_name, Gps_Utc_Model& utc)
 {
     if (utc.valid)
         {
@@ -603,7 +590,7 @@ bool gnss_sdr_supl_client::save_utc_xml(const std::string& file_name, Gps_Utc_Mo
 }
 
 
-bool gnss_sdr_supl_client::load_cnav_utc_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_cnav_utc_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -622,7 +609,7 @@ bool gnss_sdr_supl_client::load_cnav_utc_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_cnav_utc_xml(const std::string& file_name, Gps_CNAV_Utc_Model& utc)
+bool Gnss_Sdr_Supl_Client::save_cnav_utc_xml(const std::string& file_name, Gps_CNAV_Utc_Model& utc)
 {
     if (utc.valid)
         {
@@ -649,7 +636,7 @@ bool gnss_sdr_supl_client::save_cnav_utc_xml(const std::string& file_name, Gps_C
 }
 
 
-bool gnss_sdr_supl_client::load_gal_utc_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gal_utc_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -668,7 +655,7 @@ bool gnss_sdr_supl_client::load_gal_utc_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_gal_utc_xml(const std::string& file_name, Galileo_Utc_Model& utc)
+bool Gnss_Sdr_Supl_Client::save_gal_utc_xml(const std::string& file_name, Galileo_Utc_Model& utc)
 {
     if (utc.flag_utc_model)
         {
@@ -695,7 +682,7 @@ bool gnss_sdr_supl_client::save_gal_utc_xml(const std::string& file_name, Galile
 }
 
 
-bool gnss_sdr_supl_client::load_iono_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_iono_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -714,7 +701,7 @@ bool gnss_sdr_supl_client::load_iono_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_iono_xml(const std::string& file_name, Gps_Iono& iono)
+bool Gnss_Sdr_Supl_Client::save_iono_xml(const std::string& file_name, Gps_Iono& iono)
 {
     if (iono.valid)
         {
@@ -741,7 +728,7 @@ bool gnss_sdr_supl_client::save_iono_xml(const std::string& file_name, Gps_Iono&
 }
 
 
-bool gnss_sdr_supl_client::load_gal_iono_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gal_iono_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -760,9 +747,9 @@ bool gnss_sdr_supl_client::load_gal_iono_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_gal_iono_xml(const std::string& file_name, Galileo_Iono& iono)
+bool Gnss_Sdr_Supl_Client::save_gal_iono_xml(const std::string& file_name, Galileo_Iono& iono)
 {
-    if (iono.ai0_5 != 0.0)
+    if (iono.ai0 != 0.0)
         {
             std::ofstream ofs;
             try
@@ -787,7 +774,7 @@ bool gnss_sdr_supl_client::save_gal_iono_xml(const std::string& file_name, Galil
 }
 
 
-bool gnss_sdr_supl_client::load_gps_almanac_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gps_almanac_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -807,16 +794,16 @@ bool gnss_sdr_supl_client::load_gps_almanac_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_gps_almanac_xml(const std::string& file_name, std::map<int, Gps_Almanac> gps_almanac_map)
+bool Gnss_Sdr_Supl_Client::save_gps_almanac_xml(const std::string& file_name, std::map<int, Gps_Almanac> gps_almanac_map_to_save)
 {
-    if (gps_almanac_map.empty() == false)
+    if (gps_almanac_map_to_save.empty() == false)
         {
             std::ofstream ofs;
             try
                 {
                     ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
                     boost::archive::xml_oarchive xml(ofs);
-                    xml << boost::serialization::make_nvp("GNSS-SDR_gps_almanac_map", gps_almanac_map);
+                    xml << boost::serialization::make_nvp("GNSS-SDR_gps_almanac_map", gps_almanac_map_to_save);
                     LOG(INFO) << "Saved GPS almanac data";
                 }
             catch (std::exception& e)
@@ -834,7 +821,7 @@ bool gnss_sdr_supl_client::save_gps_almanac_xml(const std::string& file_name, st
 }
 
 
-bool gnss_sdr_supl_client::load_gal_almanac_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_gal_almanac_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -854,7 +841,7 @@ bool gnss_sdr_supl_client::load_gal_almanac_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::read_gal_almanac_from_gsa(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::read_gal_almanac_from_gsa(const std::string& file_name)
 {
     pugi::xml_document doc;
     pugi::xml_parse_result result = doc.load_file(file_name.c_str());
@@ -872,19 +859,19 @@ bool gnss_sdr_supl_client::read_gal_almanac_from_gsa(const std::string& file_nam
             try
                 {
                     uint32_t prn = static_cast<uint32_t>(std::stoi(almanac.child_value("SVID")));
-                    gal_alm.i_satellite_PRN = prn;
-                    gal_alm.i_Toa = std::stoi(almanac.child("almanac").child_value("t0a"));
-                    gal_alm.i_WNa = std::stoi(almanac.child("almanac").child_value("wna"));
-                    gal_alm.i_IODa = std::stoi(almanac.child("almanac").child_value("iod"));
-                    gal_alm.d_Delta_i = std::stod(almanac.child("almanac").child_value("deltai"));
-                    gal_alm.d_M_0 = std::stod(almanac.child("almanac").child_value("m0"));
-                    gal_alm.d_e_eccentricity = std::stod(almanac.child("almanac").child_value("ecc"));
-                    gal_alm.d_Delta_sqrt_A = std::stod(almanac.child("almanac").child_value("aSqRoot"));
-                    gal_alm.d_OMEGA0 = std::stod(almanac.child("almanac").child_value("omega0"));
-                    gal_alm.d_OMEGA = std::stod(almanac.child("almanac").child_value("w"));
-                    gal_alm.d_OMEGA_DOT = std::stod(almanac.child("almanac").child_value("omegaDot"));
-                    gal_alm.d_A_f0 = std::stod(almanac.child("almanac").child_value("af0"));
-                    gal_alm.d_A_f1 = std::stod(almanac.child("almanac").child_value("af1"));
+                    gal_alm.PRN = prn;
+                    gal_alm.toa = std::stoi(almanac.child("almanac").child_value("t0a"));
+                    gal_alm.WNa = std::stoi(almanac.child("almanac").child_value("wna"));
+                    gal_alm.IODa = std::stoi(almanac.child("almanac").child_value("iod"));
+                    gal_alm.delta_i = std::stod(almanac.child("almanac").child_value("deltai"));
+                    gal_alm.M_0 = std::stod(almanac.child("almanac").child_value("m0"));
+                    gal_alm.ecc = std::stod(almanac.child("almanac").child_value("ecc"));
+                    gal_alm.sqrtA = std::stod(almanac.child("almanac").child_value("aSqRoot"));
+                    gal_alm.OMEGA_0 = std::stod(almanac.child("almanac").child_value("omega0"));
+                    gal_alm.omega = std::stod(almanac.child("almanac").child_value("w"));
+                    gal_alm.OMEGAdot = std::stod(almanac.child("almanac").child_value("omegaDot"));
+                    gal_alm.af0 = std::stod(almanac.child("almanac").child_value("af0"));
+                    gal_alm.af1 = std::stod(almanac.child("almanac").child_value("af1"));
                     gal_alm.E5b_HS = std::stoi(almanac.child("svINavSignalStatus").child_value("statusE5b"));
                     gal_alm.E1B_HS = std::stoi(almanac.child("svINavSignalStatus").child_value("statusE1B"));
                     gal_alm.E5a_HS = std::stoi(almanac.child("svFNavSignalStatus").child_value("statusE5a"));
@@ -893,7 +880,7 @@ bool gnss_sdr_supl_client::read_gal_almanac_from_gsa(const std::string& file_nam
                 }
             catch (const std::exception& e)
                 {
-                    std::cerr << e.what() << std::endl;
+                    std::cerr << e.what() << '\n';
                 }
         }
     if (this->gal_almanac_map.empty())
@@ -904,16 +891,16 @@ bool gnss_sdr_supl_client::read_gal_almanac_from_gsa(const std::string& file_nam
 }
 
 
-bool gnss_sdr_supl_client::save_gal_almanac_xml(const std::string& file_name, std::map<int, Galileo_Almanac> gal_almanac_map)
+bool Gnss_Sdr_Supl_Client::save_gal_almanac_xml(const std::string& file_name, std::map<int, Galileo_Almanac> galileo_almanac_map_to_save)
 {
-    if (gal_almanac_map.empty() == false)
+    if (galileo_almanac_map_to_save.empty() == false)
         {
             std::ofstream ofs;
             try
                 {
                     ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
                     boost::archive::xml_oarchive xml(ofs);
-                    xml << boost::serialization::make_nvp("GNSS-SDR_gal_almanac_map", gal_almanac_map);
+                    xml << boost::serialization::make_nvp("GNSS-SDR_gal_almanac_map", galileo_almanac_map_to_save);
                     LOG(INFO) << "Saved Galileo almanac data";
                 }
             catch (std::exception& e)
@@ -931,7 +918,7 @@ bool gnss_sdr_supl_client::save_gal_almanac_xml(const std::string& file_name, st
 }
 
 
-bool gnss_sdr_supl_client::load_glo_utc_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_glo_utc_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -950,7 +937,7 @@ bool gnss_sdr_supl_client::load_glo_utc_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_glo_utc_xml(const std::string& file_name, Glonass_Gnav_Utc_Model& utc)
+bool Gnss_Sdr_Supl_Client::save_glo_utc_xml(const std::string& file_name, Glonass_Gnav_Utc_Model& utc)
 {
     if (utc.valid)
         {
@@ -977,7 +964,7 @@ bool gnss_sdr_supl_client::save_glo_utc_xml(const std::string& file_name, Glonas
 }
 
 
-bool gnss_sdr_supl_client::load_ref_time_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_ref_time_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -996,7 +983,7 @@ bool gnss_sdr_supl_client::load_ref_time_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_ref_time_xml(const std::string& file_name, Agnss_Ref_Time& ref_time)
+bool Gnss_Sdr_Supl_Client::save_ref_time_xml(const std::string& file_name, Agnss_Ref_Time& ref_time)
 {
     if (ref_time.valid == true)
         {
@@ -1023,7 +1010,7 @@ bool gnss_sdr_supl_client::save_ref_time_xml(const std::string& file_name, Agnss
 }
 
 
-bool gnss_sdr_supl_client::load_ref_location_xml(const std::string& file_name)
+bool Gnss_Sdr_Supl_Client::load_ref_location_xml(const std::string& file_name)
 {
     std::ifstream ifs;
     try
@@ -1042,7 +1029,7 @@ bool gnss_sdr_supl_client::load_ref_location_xml(const std::string& file_name)
 }
 
 
-bool gnss_sdr_supl_client::save_ref_location_xml(const std::string& file_name, Agnss_Ref_Location& ref_location)
+bool Gnss_Sdr_Supl_Client::save_ref_location_xml(const std::string& file_name, Agnss_Ref_Location& ref_location)
 {
     if (ref_location.valid == true)
         {
