@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -103,6 +100,7 @@ public:
                 obs->set_prompt_q(gs.Prompt_Q);
                 obs->set_cn0_db_hz(gs.CN0_dB_hz);
                 obs->set_carrier_doppler_hz(gs.Carrier_Doppler_hz);
+                obs->set_carrier_phase_rads(gs.Carrier_phase_rads);
                 obs->set_code_phase_samples(gs.Code_phase_samples);
                 obs->set_tracking_sample_counter(gs.Tracking_sample_counter);
                 obs->set_flag_valid_symbol_output(gs.Flag_valid_symbol_output);
@@ -114,6 +112,7 @@ public:
                 obs->set_pseudorange_m(gs.Pseudorange_m);
                 obs->set_rx_time(gs.RX_time);
                 obs->set_flag_valid_pseudorange(gs.Flag_valid_pseudorange);
+                obs->set_flag_pll_180_deg_phase_locked(gs.Flag_PLL_180_deg_phase_locked);
                 obs->set_interp_tow_ms(gs.interp_TOW_ms);
             }
         observables.SerializeToString(&data);
@@ -146,6 +145,8 @@ public:
                 gs.Prompt_Q = gs_read.prompt_q();
                 gs.CN0_dB_hz = gs_read.cn0_db_hz();
                 gs.Carrier_Doppler_hz = gs_read.carrier_doppler_hz();
+                gs.Carrier_phase_rads = gs_read.carrier_phase_rads();
+                gs.Code_phase_samples = gs_read.code_phase_samples();
                 gs.Tracking_sample_counter = gs_read.tracking_sample_counter();
                 gs.Flag_valid_symbol_output = gs_read.flag_valid_symbol_output();
                 gs.correlation_length_ms = gs_read.correlation_length_ms();
@@ -156,6 +157,7 @@ public:
                 gs.Pseudorange_m = gs_read.pseudorange_m();
                 gs.RX_time = gs_read.rx_time();
                 gs.Flag_valid_pseudorange = gs_read.flag_valid_pseudorange();
+                gs.Flag_PLL_180_deg_phase_locked = gs_read.flag_pll_180_deg_phase_locked();
                 gs.interp_TOW_ms = gs_read.interp_tow_ms();
 
                 vgs.push_back(gs);
