@@ -22,19 +22,20 @@
 #include "file_configuration.h"
 #include "gnss_sdr_make_unique.h"
 #include <glog/logging.h>
+#include <iostream>
 #include <utility>
 
 
 FileConfiguration::FileConfiguration(std::string filename)
+    : filename_(std::move(filename))
 {
-    filename_ = std::move(filename);
     init();
 }
 
 
 FileConfiguration::FileConfiguration()
+    : filename_("./default_config_file.txt")
 {
-    filename_ = "./default_config_file.txt";
     init();
 }
 
@@ -55,11 +56,17 @@ void FileConfiguration::init()
         }
     else
         {
-            LOG(WARNING) << "Unable to open configuration file " << filename_;
+            std::cerr << "Unable to open configuration file " << filename_ << '\n';
         }
 }
 
 
+bool FileConfiguration::has_section() const
+{
+    return ini_reader_->HasSection("GNSS-SDR");
+}
+
+
 std::string FileConfiguration::property(std::string property_name, std::string default_value) const
 {
     if (overrided_->is_present(property_name))
