@@ -1,7 +1,7 @@
 /*!
  * \file galileo_inav_message.h
  * \brief  Implementation of a Galileo I/NAV Data message
- *         as described in Galileo OS SIS ICD Issue 1.2 (Nov. 2015)
+ *         as described in Galileo OS SIS ICD Issue 2.0 (Jan. 2021)
  * \author Mara Branzanti 2013. mara.branzanti(at)gmail.com
  * \author Javier Arribas, 2013. jarribas(at)cttc.es
  *
@@ -10,7 +10,7 @@
  * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2021  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -24,12 +24,16 @@
 #include "galileo_ephemeris.h"
 #include "galileo_iono.h"
 #include "galileo_utc_model.h"
+#include "gnss_sdr_make_unique.h"  // for std::unique_ptr in C++11
 #include <bitset>
 #include <cstdint>
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
 
+class ReedSolomon;  // Forward declaration of the ReedSolomon class
+
 /** \addtogroup Core
  * \{ */
 /** \addtogroup System_Parameters
@@ -38,13 +42,15 @@
 
 /*!
  * \brief This class handles the Galileo I/NAV Data message, as described in the
- * Galileo Open Service Signal in Space Interface Control Document (OS SIS ICD), Issue 1.2 (Nov 2015).
- * See https://www.gsc-europa.eu/sites/default/files/sites/all/files/Galileo-OS-SIS-ICD.pdf
+ * Galileo Open Service Signal in Space Interface Control Document (OS SIS ICD), Issue 2.0 (Jan. 2021).
+ * See https://www.gsc-europa.eu/sites/default/files/sites/all/files/Galileo_OS_SIS_ICD_v2.0.pdf
  */
 class Galileo_Inav_Message
 {
 public:
-    Galileo_Inav_Message() = default;
+    Galileo_Inav_Message();
+
+    ~Galileo_Inav_Message();
 
     /*
      * \brief Takes in input a page (Odd or Even) of 120 bit, split it according ICD 4.3.2.3 and join Data_k with Data_j
@@ -78,6 +84,11 @@ public:
      */
     bool have_new_almanac();
 
+    /*
+     * \brief Returns true if new Reduced CED parameters have arrived. The flag is set to false when the function is executed
+     */
+    bool have_new_reduced_ced();
+
     /*
      * \brief Returns a Galileo_Ephemeris object filled with the latest navigation data received
      */
@@ -98,6 +109,11 @@ public:
      */
     Galileo_Almanac_Helper get_almanac() const;
 
+    /*
+     * \brief Returns a Galileo_Ephemeris object filled with the latest reduced CED received
+     */
+    Galileo_Ephemeris get_reduced_ced() const;
+
     inline bool get_flag_CRC_test() const
     {
         return flag_CRC_test;
@@ -148,6 +164,21 @@ public:
         flag_TOW_6 = flag_tow6;
     }
 
+    inline int32_t get_TOW0() const
+    {
+        return TOW_0;
+    }
+
+    inline bool is_TOW0_set() const
+    {
+        return flag_TOW_0;
+    }
+
+    inline void set_TOW0_flag(bool flag_tow0)
+    {
+        flag_TOW_0 = flag_tow0;
+    }
+
     inline bool get_flag_GGTO() const
     {
         return (flag_GGTO_1 == true and flag_GGTO_2 == true and flag_GGTO_3 == true and flag_GGTO_4 == true);
@@ -173,15 +204,44 @@ public:
         return WN_0G_10;
     }
 
+    /*
+     * \brief Initialize PRN field so we do not need to wait for page 4.
+     */
+    inline void init_PRN(uint32_t prn)
+    {
+        SV_ID_PRN_4 = prn;
+    }
+
+    /*
+     * \brief Enable Reed-Solomon in Galileo E1B
+     */
+    inline void enable_reed_solomon()
+    {
+        enable_rs = true;
+    }
+
 private:
-    bool CRC_test(std::bitset<GALILEO_DATA_FRAME_BITS> bits, uint32_t checksum) const;
-    bool read_navigation_bool(std::bitset<GALILEO_DATA_JK_BITS> bits, const std::vector<std::pair<int32_t, int32_t> >& parameter) const;
-    uint64_t read_navigation_unsigned(std::bitset<GALILEO_DATA_JK_BITS> bits, const std::vector<std::pair<int32_t, int32_t> >& parameter) const;
-    uint64_t read_page_type_unsigned(std::bitset<GALILEO_PAGE_TYPE_BITS> bits, const std::vector<std::pair<int32_t, int32_t> >& parameter) const;
-    int64_t read_navigation_signed(std::bitset<GALILEO_DATA_JK_BITS> bits, const std::vector<std::pair<int32_t, int32_t> >& parameter) const;
+    bool CRC_test(const std::bitset<GALILEO_DATA_FRAME_BITS>& bits, uint32_t checksum) const;
+    bool read_navigation_bool(const std::bitset<GALILEO_DATA_JK_BITS>& bits, const std::vector<std::pair<int32_t, int32_t>>& parameter) const;
+    uint64_t read_navigation_unsigned(const std::bitset<GALILEO_DATA_JK_BITS>& bits, const std::vector<std::pair<int32_t, int32_t>>& parameter) const;
+    uint64_t read_page_type_unsigned(const std::bitset<GALILEO_PAGE_TYPE_BITS>& bits, const std::vector<std::pair<int32_t, int32_t>>& parameter) const;
+    int64_t read_navigation_signed(const std::bitset<GALILEO_DATA_JK_BITS>& bits, const std::vector<std::pair<int32_t, int32_t>>& parameter) const;
+    uint8_t read_octet_unsigned(const std::bitset<GALILEO_DATA_JK_BITS>& bits, const std::vector<std::pair<int32_t, int32_t>>& parameter) const;
+    void read_page_1(const std::bitset<GALILEO_DATA_JK_BITS>& data_bits);
+    void read_page_2(const std::bitset<GALILEO_DATA_JK_BITS>& data_bits);
+    void read_page_3(const std::bitset<GALILEO_DATA_JK_BITS>& data_bits);
+    void read_page_4(const std::bitset<GALILEO_DATA_JK_BITS>& data_bits);
+    std::bitset<GALILEO_DATA_JK_BITS> regenerate_page_1(const std::vector<uint8_t>& decoded) const;
+    std::bitset<GALILEO_DATA_JK_BITS> regenerate_page_2(const std::vector<uint8_t>& decoded) const;
+    std::bitset<GALILEO_DATA_JK_BITS> regenerate_page_3(const std::vector<uint8_t>& decoded) const;
+    std::bitset<GALILEO_DATA_JK_BITS> regenerate_page_4(const std::vector<uint8_t>& decoded) const;
 
     std::string page_Even{};
 
+    std::vector<uint8_t> rs_buffer;   // Reed-Solomon buffer
+    std::unique_ptr<ReedSolomon> rs;  // The Reed-Solomon decoder
+    std::vector<int> inav_rs_pages;   // Pages 1,2,3,4,17,18,19,20. Holds 1 if the page has arrived, 0 otherwise.
+
     int32_t Page_type_time_stamp{};
     int32_t IOD_ephemeris{};
 
@@ -200,14 +260,14 @@ private:
     double iDot_2{};      // Rate of inclination angle [semi-circles/sec]
 
     // Word type 3: Ephemeris (3/4) and SISA
-    int32_t IOD_nav_3{};   //
+    int32_t IOD_nav_3{};
+    int32_t SISA_3{};
     double OMEGA_dot_3{};  // Rate of right ascension [semi-circles/sec]
     double delta_n_3{};    // Mean motion difference from computed value  [semi-circles/sec]
     double C_uc_3{};       // Amplitude of the cosine harmonic correction term to the argument of latitude [radians]
     double C_us_3{};       // Amplitude of the sine harmonic correction term to the argument of latitude [radians]
     double C_rc_3{};       // Amplitude of the cosine harmonic correction term to the orbit radius [meters]
     double C_rs_3{};       // Amplitude of the sine harmonic correction term to the orbit radius [meters]
-    int32_t SISA_3{};
 
     // Word type 4: Ephemeris (4/4) and Clock correction parameters*/
     int32_t IOD_nav_4{};    //
@@ -224,9 +284,13 @@ private:
 
     //  Word type 5: Ionospheric correction, BGD, signal health and data validity status and GST*/
     // Ionospheric correction
-    double ai0_5{};  // Effective Ionisation Level 1st order parameter [sfu]
-    double ai1_5{};  // Effective Ionisation Level 2st order parameter [sfu/degree]
-    double ai2_5{};  // Effective Ionisation Level 3st order parameter [sfu/degree]
+    double ai0_5{};        // Effective Ionisation Level 1st order parameter [sfu]
+    double ai1_5{};        // Effective Ionisation Level 2st order parameter [sfu/degree]
+    double ai2_5{};        // Effective Ionisation Level 3st order parameter [sfu/degree]
+    double BGD_E1E5a_5{};  // E1-E5a Broadcast Group Delay [s]
+    double BGD_E1E5b_5{};  // E1-E5b Broadcast Group Delay [s]
+    int32_t E5b_HS_5{};    // E5b Signal Health Status
+    int32_t E1B_HS_5{};    // E1B Signal Health Status
 
     // Ionospheric disturbance flag
     bool Region1_flag_5{};  // Ionospheric Disturbance Flag for region 1
@@ -234,13 +298,8 @@ private:
     bool Region3_flag_5{};  // Ionospheric Disturbance Flag for region 3
     bool Region4_flag_5{};  // Ionospheric Disturbance Flag for region 4
     bool Region5_flag_5{};  // Ionospheric Disturbance Flag for region 5
-    double BGD_E1E5a_5{};   // E1-E5a Broadcast Group Delay [s]
-    double BGD_E1E5b_5{};   // E1-E5b Broadcast Group Delay [s]
-
-    int32_t E5b_HS_5{};  // E5b Signal Health Status
-    int32_t E1B_HS_5{};  // E1B Signal Health Status
-    bool E5b_DVS_5{};    // E5b Data Validity Status
-    bool E1B_DVS_5{};    // E1B Data Validity Status
+    bool E5b_DVS_5{};       // E5b Data Validity Status
+    bool E1B_DVS_5{};       // E1B Data Validity Status
 
     // GST
     int32_t WN_5{};
@@ -273,11 +332,11 @@ private:
 
     // Word type 8: Almanac for SVID1 (2/2) and SVID2 (1/2)
     int32_t IOD_a_8{};
-    double af0_8{};
-    double af1_8{};
     int32_t E5b_HS_8{};
     int32_t E1B_HS_8{};
     int32_t SVID2_8{};
+    double af0_8{};
+    double af1_8{};
     double DELTA_A_8{};
     double e_8{};
     double omega_8{};
@@ -321,8 +380,25 @@ private:
     int32_t WN_0{};
     int32_t TOW_0{};
 
+    // Word type 16: Reduced Clock and Ephemeris Data (CED) parameters
+    double ced_DeltaAred{};
+    double ced_exred{};
+    double ced_eyred{};
+    double ced_Deltai0red{};
+    double ced_Omega0red{};
+    double ced_lambda0red{};
+    double ced_af0red{};
+    double ced_af1red{};
+
     double Galileo_satClkDrift{};
 
+    int32_t current_IODnav{};
+
+    uint8_t IODnav_LSB17{};
+    uint8_t IODnav_LSB18{};
+    uint8_t IODnav_LSB19{};
+    uint8_t IODnav_LSB20{};
+
     bool flag_CRC_test{};
     bool flag_all_ephemeris{};  // Flag indicating that all words containing ephemeris have been received
     bool flag_ephemeris_1{};    // Flag indicating that ephemeris 1/4 (word 1) have been received
@@ -333,6 +409,7 @@ private:
     bool flag_iono_and_GST{};  // Flag indicating that ionospheric and GST parameters (word 5) have been received
     bool flag_TOW_5{};
     bool flag_TOW_6{};
+    bool flag_TOW_0{};
     bool flag_TOW_set{};    // it is true when page 5 or page 6 arrives
     bool flag_utc_model{};  // Flag indicating that utc model parameters (word 6) have been received
 
@@ -346,6 +423,9 @@ private:
     bool flag_GGTO_2{};
     bool flag_GGTO_3{};
     bool flag_GGTO_4{};
+
+    bool flag_CED{};
+    bool enable_rs{};
 };
 
 
