@@ -28,7 +28,7 @@
 #include "in_memory_configuration.h"
 #include "observables_interface.h"
 #include "pvt_interface.h"
-#include "telemetry_decoder_interface.h"
+#include "signal_source_interface.h"
 #include "tracking_interface.h"
 #include <gtest/gtest.h>
 #include <pmt/pmt.h>
@@ -45,7 +45,7 @@ TEST(GNSSBlockFactoryTest, InstantiateFileSignalSource)
     // Example of a factory as a shared_ptr
     std::shared_ptr<GNSSBlockFactory> factory = std::make_shared<GNSSBlockFactory>();
     // Example of a block as a shared_ptr
-    std::shared_ptr<GNSSBlockInterface> signal_source = factory->GetSignalSource(configuration.get(), queue.get());
+    auto signal_source = factory->GetSignalSource(configuration.get(), queue.get());
     EXPECT_STREQ("SignalSource", signal_source->role().c_str());
     EXPECT_STREQ("File_Signal_Source", signal_source->implementation().c_str());
 }
@@ -54,12 +54,25 @@ TEST(GNSSBlockFactoryTest, InstantiateFileSignalSource)
 TEST(GNSSBlockFactoryTest, InstantiateWrongSignalSource)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
-    configuration->set_property("SignalSource.implementation", "Pepito");
+    configuration->set_property("SignalSource.implementation", "Parapsychological_Source");
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
     // Example of a factory as a unique_ptr
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     // Example of a block as a unique_ptr
-    std::unique_ptr<GNSSBlockInterface> signal_source = factory->GetSignalSource(configuration.get(), queue.get());
+    auto signal_source = factory->GetSignalSource(configuration.get(), queue.get());
+    EXPECT_EQ(nullptr, signal_source);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateWrongSignalSource2)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("SignalSource.implementation", "Pass_Through");
+    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
+    // Example of a factory as a unique_ptr
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    // Example of a block as a unique_ptr
+    auto signal_source = factory->GetSignalSource(configuration.get(), queue.get());
     EXPECT_EQ(nullptr, signal_source);
 }
 
@@ -75,6 +88,26 @@ TEST(GNSSBlockFactoryTest, InstantiateSignalConditioner)
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongSignalConditioner)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("SignalConditioner.implementation", "Signal_Ruinder");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::unique_ptr<GNSSBlockInterface> signal_conditioner = factory->GetSignalConditioner(configuration.get());
+    EXPECT_EQ(nullptr, signal_conditioner);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateWrongSignalConditioner2)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("SignalConditioner.implementation", "Fir_Filter");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::unique_ptr<GNSSBlockInterface> signal_conditioner = factory->GetSignalConditioner(configuration.get());
+    EXPECT_EQ(nullptr, signal_conditioner);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateFIRFilter)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
@@ -137,6 +170,7 @@ TEST(GNSSBlockFactoryTest, InstantiateFreqXlatingFIRFilter)
 
     configuration->set_property("InputFilter.sampling_frequency", "4000000");
     configuration->set_property("InputFilter.IF", "34000");
+
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     std::unique_ptr<GNSSBlockInterface> input_filter = factory->GetBlock(configuration.get(), "InputFilter", 1, 1);
 
@@ -150,10 +184,8 @@ TEST(GNSSBlockFactoryTest, InstantiatePulseBlankingFilter)
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
     configuration->set_property("InputFilter.implementation", "Pulse_Blanking_Filter");
-
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     std::unique_ptr<GNSSBlockInterface> input_filter = factory->GetBlock(configuration.get(), "InputFilter", 1, 1);
-
     EXPECT_STREQ("InputFilter", input_filter->role().c_str());
     EXPECT_STREQ("Pulse_Blanking_Filter", input_filter->implementation().c_str());
 }
@@ -164,10 +196,8 @@ TEST(GNSSBlockFactoryTest, InstantiateNotchFilter)
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
     configuration->set_property("InputFilter.implementation", "Notch_Filter");
-
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     std::unique_ptr<GNSSBlockInterface> input_filter = factory->GetBlock(configuration.get(), "InputFilter", 1, 1);
-
     EXPECT_STREQ("InputFilter", input_filter->role().c_str());
     EXPECT_STREQ("Notch_Filter", input_filter->implementation().c_str());
 }
@@ -178,15 +208,24 @@ TEST(GNSSBlockFactoryTest, InstantiateNotchFilterLite)
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
     configuration->set_property("InputFilter.implementation", "Notch_Filter_Lite");
-
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     std::unique_ptr<GNSSBlockInterface> input_filter = factory->GetBlock(configuration.get(), "InputFilter", 1, 1);
-
     EXPECT_STREQ("InputFilter", input_filter->role().c_str());
     EXPECT_STREQ("Notch_Filter_Lite", input_filter->implementation().c_str());
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongFilter)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
+    configuration->set_property("InputFilter.implementation", "Pollen_Filter");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::unique_ptr<GNSSBlockInterface> input_filter = factory->GetBlock(configuration.get(), "InputFilter", 1, 1);
+    EXPECT_EQ(nullptr, input_filter);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateDirectResampler)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
@@ -198,6 +237,16 @@ TEST(GNSSBlockFactoryTest, InstantiateDirectResampler)
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongResampler)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("Resampler.implementation", "RaNdOm_Resampler");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::unique_ptr<GNSSBlockInterface> resampler = factory->GetBlock(configuration.get(), "Resampler", 1, 1);
+    EXPECT_EQ(nullptr, resampler);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateGpsL1CaPcpsAcquisition)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
@@ -246,6 +295,16 @@ TEST(GNSSBlockFactoryTest, InstantiateGalileoE1PcpsAmbiguousAcquisition)
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongAcquisition)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("Acquisition.implementation", "GPS_L1_CA_PCPS_Alchemy");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> acq_ = factory->GetBlock(configuration.get(), "Acquisition", 1, 0);
+    EXPECT_EQ(nullptr, acq_);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateGpsL1CaDllPllTracking)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
@@ -282,6 +341,16 @@ TEST(GNSSBlockFactoryTest, InstantiateGalileoE1DllPllVemlTracking)
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongTracking)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("Tracking.implementation", "The perfect tracking");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> trk_ = factory->GetBlock(configuration.get(), "Tracking", 1, 1);
+    EXPECT_EQ(nullptr, trk_);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateGpsL1CaTelemetryDecoder)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
@@ -293,17 +362,35 @@ TEST(GNSSBlockFactoryTest, InstantiateGpsL1CaTelemetryDecoder)
 }
 
 
+TEST(GNSSBlockFactoryTest, InstantiateWrongTelemetryDecoder)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("TelemetryDecoder.implementation", "GPS_Xenomorphic_Telemetry_Decoder");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> telemetry_decoder = factory->GetBlock(configuration.get(), "TelemetryDecoder", 1, 1);
+    EXPECT_EQ(nullptr, telemetry_decoder);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateEmptyTelemetryDecoder)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("TelemetryDecoder.implementation", std::string(""));
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> telemetry_decoder = factory->GetBlock(configuration.get(), "TelemetryDecoder", 1, 1);
+    EXPECT_EQ(nullptr, telemetry_decoder);
+}
+
+
 TEST(GNSSBlockFactoryTest, InstantiateChannels)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     configuration->set_property("Channels_1C.count", "2");
     configuration->set_property("Channels_1E.count", "0");
     configuration->set_property("Channels.in_acquisition", "2");
+    configuration->set_property("Acquisition_1C.implementation", "GPS_L1_CA_PCPS_Acquisition");
     configuration->set_property("Tracking_1C.implementation", "GPS_L1_CA_DLL_PLL_Tracking");
     configuration->set_property("TelemetryDecoder_1C.implementation", "GPS_L1_CA_Telemetry_Decoder");
-    configuration->set_property("Channel0.item_type", "gr_complex");
-    configuration->set_property("Acquisition_1C.implementation", "GPS_L1_CA_PCPS_Acquisition");
-    configuration->set_property("Channel1.item_type", "gr_complex");
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     std::unique_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> channels = factory->GetChannels(configuration.get(), queue.get());
@@ -312,18 +399,37 @@ TEST(GNSSBlockFactoryTest, InstantiateChannels)
 }
 
 
-TEST(GNSSBlockFactoryTest, InstantiateObservables)
+TEST(GNSSBlockFactoryTest, InstantiateWrongObservables)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("Observables.implementation", "Supercalifragilistic_Observables");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    auto observables = factory->GetObservables(configuration.get());
+    EXPECT_EQ(nullptr, observables);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateWrongObservables2)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     configuration->set_property("Observables.implementation", "Pass_Through");
     std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
     auto observables = factory->GetObservables(configuration.get());
-    EXPECT_STREQ("Observables", observables->role().c_str());
-    EXPECT_STREQ("Pass_Through", observables->implementation().c_str());
+    EXPECT_EQ(nullptr, observables);
 }
 
 
-TEST(GNSSBlockFactoryTest, InstantiateGpsL1CaObservables)
+TEST(GNSSBlockFactoryTest, InstantiateWrongObservables3)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("Observables.implementation", "RTKLIB_PVT");
+    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    auto observables = factory->GetObservables(configuration.get());
+    EXPECT_EQ(nullptr, observables);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateObservables)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     configuration->set_property("Observables.implementation", "Hybrid_Observables");
@@ -350,8 +456,30 @@ TEST(GNSSBlockFactoryTest, InstantiateWrongPvt)
 {
     std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
     configuration->set_property("PVT.implementation", "Pepito");
-    std::unique_ptr<GNSSBlockFactory> factory = std::make_unique<GNSSBlockFactory>();
+    auto factory = std::make_unique<GNSSBlockFactory>();
     std::shared_ptr<GNSSBlockInterface> pvt_ = factory->GetPVT(configuration.get());
-    std::shared_ptr<PvtInterface> pvt = std::dynamic_pointer_cast<PvtInterface>(pvt_);
+    auto pvt = std::dynamic_pointer_cast<PvtInterface>(pvt_);
+    EXPECT_EQ(nullptr, pvt);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateWrongPvt2)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("PVT.implementation", "Pass_Through");
+    auto factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> pvt_ = factory->GetPVT(configuration.get());
+    auto pvt = std::dynamic_pointer_cast<PvtInterface>(pvt_);
+    EXPECT_EQ(nullptr, pvt);
+}
+
+
+TEST(GNSSBlockFactoryTest, InstantiateWrongPvt3)
+{
+    std::shared_ptr<InMemoryConfiguration> configuration = std::make_shared<InMemoryConfiguration>();
+    configuration->set_property("PVT.implementation", "Quantum_Particle_PVT");
+    auto factory = std::make_unique<GNSSBlockFactory>();
+    std::shared_ptr<GNSSBlockInterface> pvt_ = factory->GetPVT(configuration.get());
+    auto pvt = std::dynamic_pointer_cast<PvtInterface>(pvt_);
     EXPECT_EQ(nullptr, pvt);
 }
