@@ -30,6 +30,7 @@
 #include <gnuradio/blocks/skiphead.h>
 #include <gnuradio/top_block.h>
 #include <gtest/gtest.h>
+#include <pmt/pmt.h>
 #include <chrono>
 #include <utility>
 #if HAS_GENERIC_LAMBDA
@@ -41,7 +42,11 @@
 #else
 #include <gnuradio/analog/sig_source_c.h>
 #endif
-
+#if PMT_USES_BOOST_ANY
+namespace wht = boost;
+#else
+namespace wht = std;
+#endif
 
 // ######## GNURADIO BLOCK MESSAGE RECEVER #########
 class GpsL2MDllPllTrackingTest_msg_rx;
@@ -76,7 +81,7 @@ void GpsL2MDllPllTrackingTest_msg_rx::msg_handler_channel_events(const pmt::pmt_
             int64_t message = pmt::to_long(std::move(msg));
             rx_message = message;
         }
-    catch (const boost::bad_any_cast& e)
+    catch (const wht::bad_any_cast& e)
         {
             LOG(WARNING) << "msg_handler_channel_events Bad any_cast: " << e.what();
             rx_message = 0;
